summary refs log tree commit diff
path: root/nixos/modules/services/network-filesystems
diff options
context:
space:
mode:
authorSilvan Mosberger <infinisil@icloud.com>2019-05-25 21:53:23 +0200
committerGitHub <noreply@github.com>2019-05-25 21:53:23 +0200
commit0040ca936e475d34a514b480002622e641b52d90 (patch)
tree80135afb672e4e9c6524ba90ca9585d61795b21f /nixos/modules/services/network-filesystems
parentef35ad1dbc4804ac1e04c50aaa4b52647fd05553 (diff)
parent00d6b4cbc7daf19c44e81387f5d345b8ffdc461e (diff)
downloadnixpkgs-0040ca936e475d34a514b480002622e641b52d90.tar
nixpkgs-0040ca936e475d34a514b480002622e641b52d90.tar.gz
nixpkgs-0040ca936e475d34a514b480002622e641b52d90.tar.bz2
nixpkgs-0040ca936e475d34a514b480002622e641b52d90.tar.lz
nixpkgs-0040ca936e475d34a514b480002622e641b52d90.tar.xz
nixpkgs-0040ca936e475d34a514b480002622e641b52d90.tar.zst
nixpkgs-0040ca936e475d34a514b480002622e641b52d90.zip
Merge pull request #56175 from MostAwesomeDude/tahoe-service
Fix tahoe service
Diffstat (limited to 'nixos/modules/services/network-filesystems')
-rw-r--r--nixos/modules/services/network-filesystems/tahoe.nix13
1 files changed, 8 insertions, 5 deletions
diff --git a/nixos/modules/services/network-filesystems/tahoe.nix b/nixos/modules/services/network-filesystems/tahoe.nix
index 534862a3c9e..7d75eb28610 100644
--- a/nixos/modules/services/network-filesystems/tahoe.nix
+++ b/nixos/modules/services/network-filesystems/tahoe.nix
@@ -234,16 +234,19 @@ in
               Type = "simple";
               PIDFile = pidfile;
               # Believe it or not, Tahoe is very brittle about the order of
               # arguments to $(tahoe start). The node directory must come first,
               # and arguments which alter Twisted's behavior come afterwards.
               ExecStart = ''
-                ${settings.package}/bin/tahoe start ${lib.escapeShellArg nodedir} -n -l- --pidfile=${lib.escapeShellArg pidfile}
+                ${settings.package}/bin/tahoe run ${lib.escapeShellArg nodedir} --pidfile=${lib.escapeShellArg pidfile}
               '';
             };
             preStart = ''
               if [ ! -d ${lib.escapeShellArg nodedir} ]; then
                 mkdir -p /var/db/tahoe-lafs
-                tahoe create-introducer ${lib.escapeShellArg nodedir}
+                # See https://github.com/NixOS/nixpkgs/issues/25273
+                tahoe create-introducer \
+                  --hostname="${config.networking.hostName}" \
+                  ${lib.escapeShellArg nodedir}
               fi
 
               # Tahoe has created a predefined tahoe.cfg which we must now
@@ -334,10 +337,10 @@ in
               Type = "simple";
               PIDFile = pidfile;
               # Believe it or not, Tahoe is very brittle about the order of
               # arguments to $(tahoe start). The node directory must come first,
               # and arguments which alter Twisted's behavior come afterwards.
               ExecStart = ''
-                ${settings.package}/bin/tahoe start ${lib.escapeShellArg nodedir} -n -l- --pidfile=${lib.escapeShellArg pidfile}
+                ${settings.package}/bin/tahoe run ${lib.escapeShellArg nodedir} --pidfile=${lib.escapeShellArg pidfile}
               '';
             };
             preStart = ''
@@ -234,16 +234,19 @@ in
               PIDFile = pidfile;
               # Believe it or not, Tahoe is very brittle about the order of
-              # arguments to $(tahoe start). The node directory must come first,
+              # arguments to $(tahoe run). The node directory must come first,
               # and arguments which alter Twisted's behavior come afterwards.
               ExecStart = ''
@@ -334,10 +337,10 @@ in
               PIDFile = pidfile;
               # Believe it or not, Tahoe is very brittle about the order of
-              # arguments to $(tahoe start). The node directory must come first,
+              # arguments to $(tahoe run). The node directory must come first,
               # and arguments which alter Twisted's behavior come afterwards.
               ExecStart = ''